## Version 0.2.1 - 2022-01-20

* Update yaml version

## Version 0.2.0 - 2021-05-02

* Implementation get_wsgi_app_settings for the Loader

## Version 0.1.1 - 2021-04-26

* Fix default logging

## Version 0.1.0 - 2021-04-26

* Initial Release
